@@ -1,22 +1,18 @@
 import json
 
 import moto.server as server
-from moto import mock_dynamodb
-
-"""
-Test the different server responses
-"""
+from moto import mock_aws
 
 
-@mock_dynamodb
+@mock_aws
 def test_table_list():
     backend = server.create_backend_app("dynamodb")
     test_client = backend.test_client()
     res = test_client.get("/")
     assert res.status_code == 404
 
-    headers = {"X-Amz-Target": "TestTable.ListTables"}
-    res = test_client.get("/", headers=headers)
+    headers = {"X-Amz-Target": "DynamoDB_20120810.ListTables"}
+    res = test_client.post("/", headers=headers)
     assert b"TableNames" in res.data
     assert "X-Amz-Crc32" in res.headers
 
