@@ -4,6 +4,7 @@ from datetime import datetime, timedelta, timezone
 import boto3
 import pytest
 from botocore.exceptions import ClientError
+from freezegun import freeze_time
 
 from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
@@ -587,6 +588,33 @@ def test_get_records_from_empty_stream_at_timestamp():
     assert response["MillisBehindLatest"] == 0
 
 
+@freeze_time("2024-01-01 12:00:00")
+@mock_aws
+def test_get_records_at_exact_timestamp():
+    conn = boto3.client("kinesis", region_name="us-west-2")
+    stream_name = "my_stream"
+    conn.create_stream(StreamName=stream_name, ShardCount=1)
+
+    conn.put_record(StreamName=stream_name, Data="0", PartitionKey="0")
+
+    timestamp = datetime(2024, 1, 1, 12, 0, 0)
+
+    response = conn.describe_stream(StreamName=stream_name)
+    shard_id = response["StreamDescription"]["Shards"][0]["ShardId"]
+    response = conn.get_shard_iterator(
+        StreamName=stream_name,
+        ShardId=shard_id,
+        ShardIteratorType="AT_TIMESTAMP",
+        Timestamp=timestamp,
+    )
+    shard_iterator = response["ShardIterator"]
+
+    response = conn.get_records(ShardIterator=shard_iterator)
+
+    assert len(response["Records"]) == 1
+    assert response["Records"][0]["Data"] == b"0"
+
+
 @mock_aws
 def test_valid_increase_stream_retention_period():
     conn = boto3.client("kinesis", region_name="us-west-2")
