@@ -1,19 +1,21 @@
+from unittest import SkipTest, mock
 from uuid import uuid4
 
 import boto3
 import pytest
 
-from moto import mock_s3
+from moto import mock_aws, settings
 from moto.s3.responses import DEFAULT_REGION_NAME
+from tests.test_s3.test_s3 import enable_versioning
 
 from . import s3_aws_verified
 
 
-@mock_s3
+@mock_aws
 def test_list_versions():
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket = s3_resource.Bucket("foobar")
+    bucket = s3_resource.Bucket(str(uuid4()))
     bucket.create()
     bucket.Versioning().enable()
 
@@ -25,33 +27,35 @@ def test_list_versions():
     key_versions.append(key.version_id)
     assert len(key_versions) == 2
 
-    versions = client.list_object_versions(Bucket="foobar")["Versions"]
+    versions = client.list_object_versions(Bucket=bucket.name)["Versions"]
     assert len(versions) == 2
 
     assert versions[0]["Key"] == "the-key"
     assert versions[0]["VersionId"] == key_versions[1]
-    resp = client.get_object(Bucket="foobar", Key="the-key")
+    resp = client.get_object(Bucket=bucket.name, Key="the-key")
     assert resp["Body"].read() == b"Version 2"
     resp = client.get_object(
-        Bucket="foobar", Key="the-key", VersionId=versions[0]["VersionId"]
+        Bucket=bucket.name, Key="the-key", VersionId=versions[0]["VersionId"]
     )
     assert resp["Body"].read() == b"Version 2"
 
     assert versions[1]["Key"] == "the-key"
     assert versions[1]["VersionId"] == key_versions[0]
     resp = client.get_object(
-        Bucket="foobar", Key="the-key", VersionId=versions[1]["VersionId"]
+        Bucket=bucket.name, Key="the-key", VersionId=versions[1]["VersionId"]
     )
     assert resp["Body"].read() == b"Version 1"
 
     bucket.put_object(Key="the2-key", Body=b"Version 1")
 
     assert len(list(bucket.objects.all())) == 2
-    versions = client.list_object_versions(Bucket="foobar", Prefix="the2")["Versions"]
+    versions = client.list_object_versions(Bucket=bucket.name, Prefix="the2")[
+        "Versions"
+    ]
     assert len(versions) == 1
 
 
-@mock_s3
+@mock_aws
 def test_list_object_versions():
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     bucket_name = "000" + str(uuid4())
@@ -81,12 +85,10 @@ def test_list_object_versions():
 @s3_aws_verified
 def test_list_object_versions_with_delimiter(bucket_name=None):
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3_client.put_bucket_versioning(
-        Bucket=bucket_name, VersioningConfiguration={"Status": "Enabled"}
-    )
+    enable_versioning(bucket_name, s3_client)
     for key_index in list(range(1, 5)) + list(range(10, 14)):
         for version_index in range(1, 4):
-            body = f"data-{version_index}".encode("UTF-8")
+            body = f"data-{version_index}".encode()
             s3_client.put_object(
                 Bucket=bucket_name, Key=f"key{key_index}-with-data", Body=body
             )
@@ -192,7 +194,7 @@ def test_list_object_versions_with_delimiter(bucket_name=None):
     assert len(response["Versions"]) == 24
 
 
-@mock_s3
+@mock_aws
 def test_list_object_versions_with_delimiter_for_deleted_objects():
     bucket_name = "tests_bucket"
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
@@ -206,27 +208,27 @@ def test_list_object_versions_with_delimiter_for_deleted_objects():
     # Create a history of objects
     for pos in range(2):
         client.put_object(
-            Bucket=bucket_name, Key=f"obj_{pos}", Body=f"object {pos}".encode("utf-8")
+            Bucket=bucket_name, Key=f"obj_{pos}", Body=f"object {pos}".encode()
         )
 
     for pos in range(2):
         client.put_object(
             Bucket=bucket_name,
             Key=f"hist_obj_{pos}",
-            Body=f"history object {pos}".encode("utf-8"),
+            Body=f"history object {pos}".encode(),
         )
         for hist_pos in range(2):
             client.put_object(
                 Bucket=bucket_name,
                 Key=f"hist_obj_{pos}",
-                Body=f"object {pos} {hist_pos}".encode("utf-8"),
+                Body=f"object {pos} {hist_pos}".encode(),
             )
 
     for pos in range(2):
         client.put_object(
             Bucket=bucket_name,
             Key=f"del_obj_{pos}",
-            Body=f"deleted object {pos}".encode("utf-8"),
+            Body=f"deleted object {pos}".encode(),
         )
         client.delete_object(Bucket=bucket_name, Key=f"del_obj_{pos}")
 
@@ -241,10 +243,10 @@ def test_list_object_versions_with_delimiter_for_deleted_objects():
     assert [dm["Key"] for dm in del_objs["DeleteMarkers"]] == ["del_obj_0"]
 
 
-@mock_s3
+@mock_aws
 def test_list_object_versions_with_versioning_disabled():
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "mybucket"
+    bucket_name = str(uuid4())
     key = "key-with-versions"
     s3_client.create_bucket(Bucket=bucket_name)
     items = (b"v1", b"v2")
@@ -265,10 +267,10 @@ def test_list_object_versions_with_versioning_disabled():
     assert response["Body"].read() == items[-1]
 
 
-@mock_s3
+@mock_aws
 def test_list_object_versions_with_versioning_enabled_late():
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "mybucket"
+    bucket_name = str(uuid4())
     key = "key-with-versions"
     s3_client.create_bucket(Bucket=bucket_name)
     items = (b"v1", b"v2")
@@ -297,9 +299,7 @@ def test_list_object_versions_with_versioning_enabled_late():
 @s3_aws_verified
 def test_list_object_versions_with_paging(bucket_name=None):
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3_client.put_bucket_versioning(
-        Bucket=bucket_name, VersioningConfiguration={"Status": "Enabled"}
-    )
+    enable_versioning(bucket_name, s3_client)
 
     obj1ver1 = s3_client.put_object(Bucket=bucket_name, Key="obj1", Body=b"ver1")
     obj1ver2 = s3_client.put_object(Bucket=bucket_name, Key="obj1", Body=b"ver2")
@@ -351,9 +351,7 @@ def test_list_object_versions_with_paging(bucket_name=None):
 @s3_aws_verified
 def test_list_object_versions_with_paging_and_delete_markers(bucket_name=None):
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3_client.put_bucket_versioning(
-        Bucket=bucket_name, VersioningConfiguration={"Status": "Enabled"}
-    )
+    enable_versioning(bucket_name, s3_client)
 
     # A mix of versions and delete markers.
     obj1ver1 = s3_client.put_object(Bucket=bucket_name, Key="obj1", Body=b"ver1")
@@ -439,14 +437,12 @@ def test_list_object_versions_with_paging_and_delete_markers(bucket_name=None):
 def test_list_object_versions_with_paging_and_delimiter(bucket_name=None):
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
 
-    s3_client.put_bucket_versioning(
-        Bucket=bucket_name, VersioningConfiguration={"Status": "Enabled"}
-    )
+    enable_versioning(bucket_name, s3_client)
 
     # Copied from test_list_object_versions_with_delimiter.
     for key_index in list(range(1, 5)) + list(range(10, 14)):
         for version_index in range(1, 4):
-            body = f"data-{version_index}".encode("UTF-8")
+            body = f"data-{version_index}".encode()
             s3_client.put_object(
                 Bucket=bucket_name, Key=f"key{key_index}-with-data", Body=body
             )
@@ -529,10 +525,10 @@ def test_list_object_versions_with_paging_and_delimiter(bucket_name=None):
     assert "NextVersionIdMarker" not in page3
 
 
-@mock_s3
+@mock_aws
 def test_bad_prefix_list_object_versions():
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "mybucket"
+    bucket_name = str(uuid4())
     key = "key-with-versions"
     bad_prefix = "key-that-does-not-exist"
     s3_client.create_bucket(Bucket=bucket_name)
@@ -552,14 +548,11 @@ def test_bad_prefix_list_object_versions():
 @s3_aws_verified
 def test_list_object_versions__sort_order(bucket_name=None):
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3_client.put_bucket_versioning(
-        Bucket=bucket_name, VersioningConfiguration={"Status": "Enabled"}
-    )
+    enable_versioning(bucket_name, s3_client)
 
     # Put one object, and delete it
-    b_ver1 = s3_client.put_object(Bucket=bucket_name, Key="bbb", Body=b"ver1")[
-        "VersionId"
-    ]
+    upl = s3_client.put_object(Bucket=bucket_name, Key="bbb", Body=b"ver1")
+    b_ver1 = upl["ResponseMetadata"]["HTTPHeaders"]["x-amz-version-id"]
 
     b_del = s3_client.delete_object(Bucket=bucket_name, Key="bbb")["VersionId"]
 
@@ -638,3 +631,57 @@ def test_list_object_versions__sort_order(bucket_name=None):
     assert version_list["Versions"][2]["VersionId"] == b_ver1
     assert len(version_list["DeleteMarkers"]) == 1
     assert version_list["DeleteMarkers"][0]["VersionId"] == b_del
+
+
+@mock_aws
+@mock.patch.dict("os.environ", {"MOTO_S3_DEFAULT_MAX_KEYS": "5"})
+def test_list_object_versions_with_custom_limit():
+    if not settings.TEST_DECORATOR_MODE:
+        raise SkipTest("Can only set env var in DecoratorMode")
+    s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
+    bucket_name = str(uuid4())
+    bucket = s3_resource.Bucket(bucket_name)
+    bucket.create()
+    bucket.Versioning().enable()
+
+    for i in range(10):
+        s3_client.put_object(
+            Bucket=bucket_name, Key="obj", Body=b"ver" + str(i).encode("utf-8")
+        )
+
+    page1 = s3_client.list_object_versions(Bucket=bucket_name)
+    assert page1["MaxKeys"] == 5
+    assert len(page1["Versions"]) == 5
+
+
+@mock_aws
+def test_list_object_versions_is_latest_flag_is_correct_when_response_is_paginated():
+    bucket_name = "test-bucket"
+    valid = 500
+    deleted = 501
+    s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    s3_client.create_bucket(Bucket=bucket_name)
+    s3_client.put_bucket_versioning(
+        Bucket=bucket_name, VersioningConfiguration={"Status": "Enabled"}
+    )
+    for i in range(valid + deleted):
+        key = f"mongodb/object-{i}"
+        s3_client.put_object(Bucket=bucket_name, Key=key, Body=b"content")
+        if i >= valid:
+            s3_client.delete_object(Bucket=bucket_name, Key=key)
+
+    first_page = s3_client.list_object_versions(
+        Bucket=bucket_name, Prefix="mongodb/", MaxKeys=1000
+    )
+    assert first_page["DeleteMarkers"][-1]["Key"] == "mongodb/object-761"
+    assert first_page["DeleteMarkers"][-1]["IsLatest"] is True
+    second_page = s3_client.list_object_versions(
+        Bucket=bucket_name,
+        Prefix="mongodb/",
+        MaxKeys=1000,
+        KeyMarker=first_page["NextKeyMarker"],
+        VersionIdMarker=first_page["NextVersionIdMarker"],
+    )
+    assert second_page["Versions"][0]["Key"] == "mongodb/object-761"
+    assert second_page["Versions"][0]["IsLatest"] is False
