@@ -1,22 +1,21 @@
-from datetime import datetime
+from datetime import datetime, timezone
 from unittest import SkipTest
 
-from dateutil.parser import parse as dtparse
 from freezegun import freeze_time
 
-from moto import mock_swf, settings
+from moto import mock_aws, settings
 
-from ..utils import SCHEDULE_ACTIVITY_TASK_DECISION, setup_workflow_boto3
+from ..utils import SCHEDULE_ACTIVITY_TASK_DECISION, setup_workflow
 
 
 # Activity Task Heartbeat timeout
 # Default value in workflow helpers: 5 mins
-@mock_swf
-def test_activity_task_heartbeat_timeout_boto3():
+@mock_aws
+def test_activity_task_heartbeat_timeout():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("Unable to manipulate time in ServerMode")
     with freeze_time("2015-01-01 12:00:00"):
-        client = setup_workflow_boto3()
+        client = setup_workflow()
         decision_token = client.poll_for_decision_task(
             domain="test-domain", taskList={"name": "queue"}
         )["taskToken"]
@@ -47,20 +46,19 @@ def test_activity_task_heartbeat_timeout_boto3():
         attrs = resp["events"][-2]["activityTaskTimedOutEventAttributes"]
         assert attrs["timeoutType"] == "HEARTBEAT"
         # checks that event has been emitted at 12:05:00, not 12:05:30
-        assert isinstance(resp["events"][-2]["eventTimestamp"], datetime)
         ts = resp["events"][-2]["eventTimestamp"]
-        assert ts == dtparse("2015-01-01 12:05:00 UTC")
+        assert ts == datetime(2015, 1, 1, 12, 5, 00, tzinfo=timezone.utc)
 
 
 # Decision Task Start to Close timeout
 # Default value in workflow helpers: 5 mins
-@mock_swf
-def test_decision_task_start_to_close_timeout_boto3():
+@mock_aws
+def test_decision_task_start_to_close_timeout():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("Unable to manipulate time in ServerMode")
 
     with freeze_time("2015-01-01 12:00:00 UTC"):
-        client = setup_workflow_boto3()
+        client = setup_workflow()
         client.poll_for_decision_task(domain="test-domain", taskList={"name": "queue"})
 
     with freeze_time("2015-01-01 12:04:30 UTC"):
@@ -98,19 +96,18 @@ def test_decision_task_start_to_close_timeout_boto3():
             "timeoutType": "START_TO_CLOSE",
         }
         # checks that event has been emitted at 12:05:00, not 12:05:30
-        assert isinstance(resp["events"][-2]["eventTimestamp"], datetime)
         ts = resp["events"][-2]["eventTimestamp"]
-        assert ts == dtparse("2015-01-01 12:05:00 UTC")
+        assert ts == datetime(2015, 1, 1, 12, 5, 00, tzinfo=timezone.utc)
 
 
 # Workflow Execution Start to Close timeout
 # Default value in workflow helpers: 2 hours
-@mock_swf
-def test_workflow_execution_start_to_close_timeout_boto3():
+@mock_aws
+def test_workflow_execution_start_to_close_timeout():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("Unable to manipulate time in ServerMode")
     with freeze_time("2015-01-01 12:00:00 UTC"):
-        client = setup_workflow_boto3()
+        client = setup_workflow()
 
     with freeze_time("2015-01-01 13:59:30 UTC"):
         resp = client.get_workflow_execution_history(
@@ -137,6 +134,5 @@ def test_workflow_execution_start_to_close_timeout_boto3():
         attrs = resp["events"][-1]["workflowExecutionTimedOutEventAttributes"]
         assert attrs == {"childPolicy": "ABANDON", "timeoutType": "START_TO_CLOSE"}
         # checks that event has been emitted at 14:00:00, not 14:00:30
-        assert isinstance(resp["events"][-1]["eventTimestamp"], datetime)
         ts = resp["events"][-1]["eventTimestamp"]
-        assert ts == dtparse("2015-01-01 14:00:00 UTC")
+        assert ts == datetime(2015, 1, 1, 14, 0, 00, tzinfo=timezone.utc)
